JSDoc: Module: SlickGridShapes

# Module: SlickGridShapes

SlickGrid shape editor and formatter.

Source:
  - shape-editor.js, line 1

### Classes

ShapeEditor

### Methods

#### (inner) ShapeFormatter(row, cell, value, columnDef, dataContext) → {string}

Function to format shape dropdown for the SlickGrid object.

This formatter is heavily based in the examples found in slick.formattters.js.

##### Parameters:

Name | Type | Description
--- | --- | ---
`row` | Object | SlickGrid row.
`cell` | Object | SlickGrid cell.
`value` | string | the value in the row.
`columnDef` | Objecy | SlickGrid column definition.
`dataContext` | Object | data model of the SlickGrid object

Source:
  - shape-editor.js, line 84

##### Returns:

The HTML of the div and value

Type
  string